@@ -1,20 +1,28 @@
-( cd opt/kde/share/doc/HTML/da/kchart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kchart ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kformula ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kformula ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kexi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kexi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kivio ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kivio ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/koffice ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/koffice ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/koshell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/koshell ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kpresenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kpresenter ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kspread ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kspread ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/krita ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/krita ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kugar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kugar ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kword ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/koffice ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/koffice ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/koshell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/koshell ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kspread ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kspread ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/karbon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/karbon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kchart ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kpresenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kpresenter ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kplato ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kplato ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/thesaurus ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kformula ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kformula ; ln -sf /opt/kde/share/doc/HTML/da/common common )
